# Generated by Django 3.1.2 on 2020-10-13 16:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('activityLibrary', '0002_auto_20201013_1315'),
    ]

    operations = [
        migrations.AddField(
            model_name='recipe',
            name='ingredients',
            field=models.ManyToManyField(blank=True, to='activityLibrary.Ingredient'),
        ),
    ]



# Generated by Django 3.1.2 on 2020-10-15 07:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0003_auto_20201015_0641'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='profile',
            name='current_weight',
        ),
    ]



# Generated by Django 3.1.2 on 2020-10-15 20:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0004_remove_profile_current_weight'),
    ]

    operations = [
        migrations.AddField(
            model_name='profile',
            name='carb_percent',
            field=models.DecimalField(decimal_places=1, default=55, help_text='Recommended Carbohydrate intake is between 45-65%', max_digits=3),
        ),
        migrations.AddField(
            model_name='profile',
            name='current_weight',
            field=models.IntegerField(default=0, help_text='Enter in lbs'),
        ),
        migrations.AddField(
            model_name='profile',
            name='fat_percent',
            field=models.DecimalField(decimal_places=1, default=25, help_text='Recommended fat intake is between 20-25%', max_digits=3),
        ),
        migrations.AddField(
            model_name='profile',
            name='protein_percent',
            field=models.DecimalField(decimal_places=1, default=20, help_text='Recommended Carbohydrate intake is between 80-100% of current body weight%', max_digits=3),
        ),
    ]



from django.db import models
from django.utils import timezone
from django.contrib.auth.models import User
from django.utils import timezone

class Activity(models.Model):
    title = models.CharField(max_length=100)
    summary = models.TextField()
    icon = models.ImageField(default='default.jpg',upload_to='activity_thumbnails')


class Exercise(Activity):
    demo = models.URLField()
    targetMuscle = models.CharField(max_length=100)

    def __str__(self):
        return self.title

class ScheduledExercise(Exercise):
    date = models.DateTimeField(default=timezone.now)
    user = models.ForeignKey(User, on_delete=models.CASCADE)

    def __str__(self):
        return self.title

class Ingredient(models.Model):
    name = models.CharField(max_length=100)
    vegetarian = models.BooleanField()
    vegan = models.BooleanField()

class Recipe(Activity):
    calories = models.IntegerField()
    carbs = models.IntegerField()
    fat = models.IntegerField()
    protein = models.IntegerField()
    cook_duration_mins = models.IntegerField()
    ingredients = models.ManyToManyField(Ingredient, blank=True)

    def __str__(self):
        return self.title

class ScheduledMeal(Recipe):
    date = models.DateTimeField(default=timezone.now)
    user = models.ForeignKey(User, on_delete=models.CASCADE)
    
    def __str__(self):
        return self.title





# Generated by Django 3.1.2 on 2020-10-16 05:50

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('users', '0006_auto_20201015_1921'),
    ]

    operations = [
        migrations.CreateModel(
            name='Food',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('carbs', models.IntegerField()),
                ('fats', models.IntegerField()),
                ('protein', models.IntegerField()),
                ('calories', models.IntegerField()),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]



from django import forms
from django.contrib.auth.models import User
from django.contrib.auth.forms import UserCreationForm
from .models import Profile
from .models import WeightRecord
from .models import LiftRecord2
from .models import Food

class UserRegisterForm(UserCreationForm):
    email = forms.EmailField()

    class Meta:
        model = User
        fields = ['username', 'email', 'password1', 'password2']

class ProfileForm(forms.ModelForm):
    class Meta:
        model = Profile
        #we probably want to change the labels of the fields on the front end
        #example: daily_cal_in = forms.IntegerField(label="Daily Calories")
        fields = ['daily_cal_in', 'daily_carbs', 'daily_fat', 'daily_protein','starting_weight', 'goal_weight_change','activity_level']

class WeightForm(forms.ModelForm):
    class Meta:
        model = WeightRecord
        fields = ['lbs', 'date']

class Lift2Form(forms.ModelForm):
    class Meta:
        model = LiftRecord2
        fields = ['name','weight', 'sets', 'reps', 'date']

class FoodForm(forms.ModelForm):
    class Meta:
        model = Food
        fields = ['name','carbs', 'fats', 'protein', 'date']

class OptionForm(forms.Form):
    optionName = forms.ChoiceField()



# Generated by Django 3.1.2 on 2020-10-16 05:52

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0007_food'),
    ]

    operations = [
        migrations.AddField(
            model_name='food',
            name='date',
            field=models.DateField(default=django.utils.timezone.now),
        ),
    ]



# Generated by Django 3.1.2 on 2020-10-15 04:56

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('activityLibrary', '0004_auto_20201014_1327'),
        ('activityLibrary', '0004_auto_20201013_2120'),
    ]

    operations = [
    ]



# Generated by Django 3.1.2 on 2020-10-14 09:11

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Profile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('profile_picture', models.ImageField(default='default.jpg', upload_to='profile_pics')),
                ('daily_cal_in', models.IntegerField()),
                ('daily_carbs', models.IntegerField()),
                ('daily_fat', models.IntegerField()),
                ('daily_protein', models.IntegerField()),
                ('goal_weight_change', models.IntegerField()),
                ('activity_level', models.DecimalField(decimal_places=1, max_digits=2)),
                ('current_weight', models.IntegerField()),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]



# Generated by Django 3.1.2 on 2020-10-12 22:44

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Activity',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=100)),
                ('summary', models.TextField()),
                ('icon', models.ImageField(upload_to='')),
                ('scheduled_date', models.DateField(default=django.utils.timezone.now)),
            ],
        ),
        migrations.CreateModel(
            name='Exercise',
            fields=[
                ('activity_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='activityLibrary.activity')),
                ('demo', models.URLField()),
                ('targetMuscle', models.CharField(max_length=100)),
            ],
            bases=('activityLibrary.activity',),
        ),
        migrations.CreateModel(
            name='Recipe',
            fields=[
                ('activity_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='activityLibrary.activity')),
                ('calories', models.IntegerField()),
                ('carbs', models.IntegerField()),
                ('fat', models.IntegerField()),
                ('protein', models.IntegerField()),
                ('cook_duration_mins', models.IntegerField()),
            ],
            bases=('activityLibrary.activity',),
        ),
        migrations.CreateModel(
            name='Ingredients',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('vegetarian', models.BooleanField()),
                ('veagan', models.BooleanField()),
                ('recipes', models.ManyToManyField(blank=True, to='activityLibrary.Recipe')),
            ],
        ),
    ]
